<?php
/**
 * Created by METHIS Dialogmarketing GmbH.
 * User: she
 * Date: 30.04.14
 * Time: 16:44
 */

/**
 * reads and returns the plugin's meta information
 * @param string $p_str_MetaInformation
 * @return string
 */
function forms_contact_plugin_metadata($p_str_MetaInformation) {
	$l_arr_MetaData = array(
		'Name' => 'Plugin Name',
		'PluginURI' => 'Plugin URI',
		'Version' => 'Version',
		'Description' => 'Description',
		'Author' => 'Author',
		'AuthorURI' => 'Author URI',
		'TextDomain' => 'Text Domain',
		'DomainPath' => 'Domain Path',
		'Network' => 'Network'
	);

	$l_arr_plugin_data = get_file_data(dirname(__FILE__) . "/index.php", $l_arr_MetaData, 'plugin');
	if (array_key_exists($p_str_MetaInformation, $l_arr_plugin_data)) {
		return $l_arr_plugin_data[$p_str_MetaInformation];
	}
	return "";
}


/**
 * reads a option field, filters the values and returns the filtered option array
 * @param string $p_str_OptionsField
 * @return array
 */
function forms_contact_filter_options($p_str_OptionsField, $p_arr_Default = array())
{
	$l_arr_Options = get_option($p_str_OptionsField);
	// check if settings are an valid array
	if (!is_array($l_arr_Options) || empty($l_arr_Options)) {
		// is setting is a string (just 1 setting parameter), return it
		if (is_string($l_arr_Options)) {
			return $l_arr_Options;
		}
		return $p_arr_Default;
	}
	/* loop through all keys in the array and filters them */
	foreach ($l_arr_Options as $l_str_Key => $l_str_Value) {
		$l_arr_Options[$l_str_Key] = forms_contact_filter_value($l_str_Value);
	}
	/* returns the filtered array */
	return $l_arr_Options;
}

/**
 * filters a string and returns the filtered value
 * @param string $p_str_Value
 * @return string
 */
function forms_contact_filter_value($p_str_Value) {
	/* strips quotes */
	$p_str_Value = stripcslashes($p_str_Value);
	/* replace "http://" at the beginning of a string */
	if (startsWith($p_str_Value, "http://")) {
		$p_str_Value = str_replace("http://", "", $p_str_Value);
	}
	/* replace "https://" at the beginning of a string */
	if (startsWith($p_str_Value, "https://")) {
		$p_str_Value = str_replace("https://", "", $p_str_Value);
	}
	/* returns the filtered string */
	return $p_str_Value;
}

/**
 * returs true if string starts with needle
 * @param string $p_str_haystack
 * @param string $p_str_needle
 * @return bool
 * http://stackoverflow.com/questions/834303/php-startswith-and-endswith-functions
 */
function startsWith($p_str_haystack, $p_str_needle) {
	return $p_str_needle === "" || strpos($p_str_haystack, $p_str_needle) === 0;
}

/**
 * converts a date in the localization specific format, default will be "day.month.year"
 * @param string $p_str_day
 * @param string $p_str_month
 * @param string $p_str_year
 * @return string
 */
function forms_contact_convertDate($p_str_day, $p_str_month, $p_str_year)
{
	/* read current wordpress langauge */
	$l_str_locale = apply_filters('plugin_locale', get_locale(), FORMS_CONTACT_PLUGIN_NAME);

	/* convert date depending on wordpress localization */
	switch($l_str_locale) {
		case "en_US":
			return $p_str_month . "/" . $p_str_day . "/" . $p_str_year;
			break;
		/* all other localizations have default: day.month.year format */
		default:
			return $p_str_day . "." . $p_str_month . "." . $p_str_year;
			break;
	}
}

/**
 * reads the wordpress langauge and returns only the language code lowercase
 * removes the localization code
 * @return string (only the "en" from "en_US")
 */
function forms_contact_getLanguageCode()
{
	/* read current wordpress langauge */
	$l_str_locale = apply_filters('plugin_locale', get_locale(), FORMS_CONTACT_PLUGIN_NAME);
	/* check if wordpress language has a localization (e.g. "en_US" or "de_AT") */
	if (strpos($l_str_locale, "_") !== false) {
		/* remove localization code */
		$l_arr_languageCode = explode("_", $l_str_locale);
		$l_str_languageCode = $l_arr_languageCode[0];
		return $l_str_languageCode;
	}
	/* return language code lowercase */
	return strtolower($l_str_locale);
}

/**
 * loads the langauge file including localization if exists
 * otherwise loads the langauge file without localization information
 */
function forms_contact_load_language()
{
	/* read current wordpress langauge */
	$l_str_locale = apply_filters('plugin_locale', get_locale(), FORMS_CONTACT_PLUGIN_NAME);
	/* get only language code (removed localization code) */
	$l_str_languageCode = forms_contact_getLanguageCode();

	/* language file with localization exists */
	if ($l_bool_loaded = load_textdomain(FORMS_CONTACT_PLUGIN_NAME, dirname(__FILE__) . '/languages/' . FORMS_CONTACT_PLUGIN_NAME . '-' . $l_str_locale . '.mo')) {

	/* language file without localization exists */
	} else if ($l_bool_loaded = load_textdomain(FORMS_CONTACT_PLUGIN_NAME, dirname(__FILE__) . '/languages/' . FORMS_CONTACT_PLUGIN_NAME . '-' . $l_str_languageCode . '.mo')) {

	/* load default language file, nothing will happen: default language will be used (=english) */
	} else {
		load_textdomain(FORMS_CONTACT_PLUGIN_NAME, dirname(__FILE__) . '/languages/' . FORMS_CONTACT_PLUGIN_NAME . '-en.mo');
		//load_plugin_textdomain(FORMS_CONTACT_PLUGIN_NAME, false, dirname(plugin_basename(__FILE__)) . '/languages/');
	}
}

/**
 * replace the /forms.contact placeholder with an iFrame tag to display the /forms.contact forms
 * @param string $p_str_Content
 * @param string $p_str_Placeholder
 * @param string $p_str_Language
 * @param string $p_str_TermsConditions
 * @param string $p_str_Page
 * @param string $p_str_SpecialParameters [optional]
 * @return string
 */
function forms_contact_replace_placeholders($p_str_Content, $p_str_Placeholder, $p_str_Language, $p_str_TermsConditions, $p_str_Page, $p_str_SpecialParameters = "")
{
	/* get wordpress version */
	global $wp_version;
	/* create the link for the iFrame source */
	$l_str_Link = FORMS_CONTACT_HOST .
		"?page=" . $p_str_Page .
		"&host=" . $_SERVER["HTTP_HOST"] .
		"&framework=" . "WordPress" .
		"&frameworkversion=" . $wp_version .
		"&plugin=" . FORMS_CONTACT_PLUGIN_NAME .
		"&pluginversion=" . forms_contact_plugin_metadata('Version') .
		"&lang=" . $p_str_Language .
		"&terms=" . $p_str_TermsConditions;

	/* add special parameters to the iFrame source if set */
	if (!empty($p_str_SpecialParameters)) {
		$l_str_Link .= "&" . $p_str_SpecialParameters;
	}

	/* replace all occurence of /forms.contact placeholders in current page */
	do {
		/* create a unique id for the iFrame, if more then 1 replacement per page */
		$l_str_iFrameUniqueID = "forms_contact_iframe_resizeable_" . rand(10000, 99999);

		/* javascript function to rezie the iFrame tag depending on its content */
		$l_str_Script = '
			<script type="text/javascript">
				jQuery(document).ready(function () {
					jQuery("#' . $l_str_iFrameUniqueID . '").iFrameResize();
				});
			</script>
		';

		/* create iFrame with page specific link and unique id */
		$l_str_PlaceholderText = '
			<div class="embed-container">
				<iframe id="' . $l_str_iFrameUniqueID . '" src="' . $l_str_Link . '" width="100%"></iframe>
			</div>
		';

		/* get first occurence of placeholder */
		$l_int_Count = strpos($p_str_Content, $p_str_Placeholder);
		if ($l_int_Count !== false) {
			$p_str_Content = substr_replace($p_str_Content, $l_str_Script . $l_str_PlaceholderText, $l_int_Count, strlen($p_str_Placeholder));
			/* no occurency found, nothing to replace in page content */
		} else {
			return $p_str_Content;
		}
	} while (true);
}

/**
 * replace the /forms.contact placeholders in the current public page
 * @param string $p_str_Content
 * @return string
 */
function forms_contact_replace_public_placeholders($p_str_Content)
{
	/* get all /forms.contact values from database */
	$l_arr_Values = forms_contact_filter_options(FORMS_CONTACT_SETTINGS_CONTAINER, forms_contact_class_settings::$default_settings);
	/* get campaign code */
	$l_str_CampaignCode = $l_arr_Values[FORMS_CONTACT_SETTINGS_INPUT_CAMPAIGNCODE_NAME];
	/* get /forms.contact language */
	$l_str_Language = $l_arr_Values[FORMS_CONTACT_SETTINGS_INPUT_LANGUAGE_NAME];
	/* get /forms.contact terms&conditions */
	$l_str_TermsConditions = $l_arr_Values[FORMS_CONTACT_SETTINGS_INPUT_TAC_PROTOCOL_NAME] . "://" . $l_arr_Values[FORMS_CONTACT_SETTINGS_INPUT_TAC_NAME];

	/* javascript to resize the iFrame tag depending on its content */
	$l_str_ExternalScripts = '<script type="text/javascript" src="' . plugins_url('js/iframeResizer.min.js', __FILE__) . '"></script>';

	/* add external js script link only once at the beginning of the page's content */
	$p_str_Content = $l_str_ExternalScripts . $p_str_Content;

	/* replaces the /forms.contact placeholder on the current public page */
	$p_str_Content = forms_contact_replace_placeholders($p_str_Content, FORMS_CONTACT_PLACEHOLDER, $l_str_Language, $l_str_TermsConditions, "form", "CampaignCode=" . $l_str_CampaignCode);

	/* replaces the /forms.contact order placeholder on the current public page */
	$p_str_Content = forms_contact_replace_placeholders($p_str_Content, FORMS_CONTACT_ORDER_PLACEHOLDER, $l_str_Language, $l_str_TermsConditions, "order", "");

	/* replaces the /forms.contact payment placeholder on the current public page */
	$p_str_Content = forms_contact_replace_placeholders($p_str_Content, FORMS_CONTACT_PAYMENT_PLACEHOLDER, $l_str_Language, $l_str_TermsConditions, "payment", "");

	/* replaces the /forms.contact dummy placeholder on the current public page */
	$p_str_Content = forms_contact_replace_placeholders($p_str_Content, FORMS_CONTACT_DUMMY_PLACEHOLDER, $l_str_Language, $l_str_TermsConditions, "form_dummy", "");

	/* return content with iFrame tags */
	return $p_str_Content;
}

/**
 * add short links to the plugin main page
 * @param array $links
 * @param mixed $file
 * @return array
 */
function forms_contact_plugin_settings_link($links, $file)
{
	/* add link to the /forms.contact plugin's settings page */
	$settings_link = '<a href="' . admin_url('options-general.php?page=' . FORMS_CONTACT_SETTINGS_PAGE_ID) . '">' . __('Settings', FORMS_CONTACT_PLUGIN_NAME) . '</a>';
	array_unshift($links, $settings_link);

	/* return new links */
	return $links;
}