<?php
/**
 * Created by METHIS Dialogmarketing GmbH.
 * User: she
 * Date: 30.04.14
 * Time: 16:21
 */

/**
 * Class forms_contact_class_plugin
 */
class forms_contact_class_plugin
{
	var $settings, $options_page; /* class attributes */

	/**
	 * @constructor
	 */
	function __construct()
	{
		/* load settings only if current wordpress user is admin */
		if (is_admin()) {
			/* create a new instance of the class settings */
			$this->settings = new forms_contact_class_settings();
		}

		/* execute class function: init, admin_init and admin_menu */
		add_action('init', array($this, 'init'));
		add_action('admin_init', array($this, 'admin_init'));
		add_action('admin_menu', array($this, 'admin_menu'));

		/* register hook for activating the plugin */
		register_activation_hook(__FILE__, array($this, 'activate'));
		/* register hook for deactivating the plugin */
		register_deactivation_hook(__FILE__, array($this, 'deactivate'));
		/* register hook for uninstalling the plugin */
		register_uninstall_hook(__FILE__, array(__CLASS__, 'uninstall'));

		/* checks if the current version is the newest version */
		$this->update();
	}

	/**
	 * activates the plugin
	 */
	function activate()
	{
	}

	/**
	 * deactivates the plugin
	 */
	function deactivate()
	{
	}

	/**
	 * uninstalls the plugin
	 */
	function uninstall()
	{
		require_once(PLUGIN_DIR . 'uninstall.php');
	}

	/**
	 * returns the current plugin version from database
	 * @return string
	 */
	function getCurrentPluginVersion()
	{
		return forms_contact_filter_options(FORMS_CONTACT_PLUGIN_VERSION_DATABASE_CONTAINER);
	}

	/**
	 * returns true when the actual version is the newest version
	 * @return bool
	 */
	function isCurrentVersion()
	{
		/* gets current plugin version */
		$l_str_Version = $this->getCurrentPluginVersion();
		/* compares plugin version from database with plugin define, true when equal */
		return version_compare($l_str_Version, forms_contact_plugin_metadata('Version'), '=') ? true : false;
	}

	/**
	 * check if the plugin needs an update and executes the update script it
	 * returns the new version
	 * @return string
	 */
	function update()
	{
		/* compares current plugin version with the new version */
		if (!$this->isCurrentVersion()) {
			// TODO: Do some special things when we update to version x.x.x
		}

		/* updates the version in database to the new one */
		update_option(FORMS_CONTACT_PLUGIN_VERSION_DATABASE_CONTAINER, forms_contact_plugin_metadata('Version'));
		/* return the new version */
		return forms_contact_plugin_metadata('Version');
	}

	/**
	 * initialize function
	 * called in the class constructor
	 */
	function init()
	{
	}

	/**
	 * do admin init stuff
	 * called in the class constructor
	 */
	function admin_init()
	{
	}

	/**
	 * do admin menu stuff
	 * called in the class constructor
	 */
	function admin_menu()
	{
	}

} /* class forms_contact_class_plugin */