<?php
/**
 * Created by METHIS Dialogmarketing GmbH.
 * User: she
 * Date: 29.04.14
 * Time: 15:01
 */

/**
 * Class forms_contact_class_settings
 */
class forms_contact_class_settings
{
	/* attribute for default settings value */
	public static $default_settings = array(
		FORMS_CONTACT_SETTINGS_INPUT_CAMPAIGNCODE_NAME => '',
		FORMS_CONTACT_SETTINGS_INPUT_LANGUAGE_NAME => '',
		FORMS_CONTACT_SETTINGS_INPUT_TAC_NAME => '',
		FORMS_CONTACT_SETTINGS_INPUT_TAC_PROTOCOL_NAME => ''
	);
	var $pagehook, $page_id, $settings_field, $options; /* class attributes */

	private $a_arr_CampaignCode; /* contains the campaign code read from database */
	private $a_arr_Language; /* contains the /forms.contact language read from database */
	private $a_arr_TaCLink; /* contains the link to terms&conditions */
	private $a_arr_TaCProtocolLink; /* contains the protocol for the link to the terms&conditions */

	/**
	 * @constructor
	 */
	function __construct()
	{
		$this->page_id = FORMS_CONTACT_SETTINGS_PAGE_ID;
		/* This is the get_options slug used in the database to store our plugin option values. */
		$this->settings_field = FORMS_CONTACT_SETTINGS_CONTAINER;
		/* read plugin settings from database */
		$this->options = forms_contact_filter_options($this->settings_field, self::$default_settings);

		/* execute class functions: admin_init and admin_menu */
		add_action('admin_init', array($this, 'admin_init'), 20);
		add_action('admin_menu', array($this, 'admin_menu'), 20);
	}

	/**
	 * initialize settings page
	 * called in class constructor
	 */
	function admin_init()
	{
		/* add the jQuery plugin to the settings page */
		wp_enqueue_script('jquery');
		/* register the iFrameResizer plugin from local directory. the iFrameResizer plugin auto. resizes an iFrame tag depending on its content */
		wp_register_script('iframeresizer', plugins_url('js/iframeResizer.min.js', __FILE__));
		/* add the iFrameResizer plugin to the settings page */
		wp_enqueue_script('iframeresizer');
		/* register stylesheet for the settings page */
		wp_register_style('forms_contact_settings_style', plugins_url('css/settings.css', __FILE__));
		/* add stylesheet to the settings page */
		wp_enqueue_style('forms_contact_settings_style');
		/* Needed to allow metabox layout and close functionality */
		wp_enqueue_script('postbox');

		/* register the settings and sanitize the values loaded from database */
		register_setting($this->settings_field, $this->settings_field, array($this, 'sanitize_theme_options'));
		/* adds the values from database to the options array or adds the default values if the database values are invalid */
		add_option($this->settings_field, self::$default_settings);

		/* read campaign code from database */
		$this->a_arr_CampaignCode = array();
		$this->a_arr_CampaignCode["id"] = $this->get_field_id(FORMS_CONTACT_SETTINGS_INPUT_CAMPAIGNCODE_NAME);
		$this->a_arr_CampaignCode["name"] = $this->get_field_name(FORMS_CONTACT_SETTINGS_INPUT_CAMPAIGNCODE_NAME);
		$this->a_arr_CampaignCode["value"] = esc_attr($this->get_field_value(FORMS_CONTACT_SETTINGS_INPUT_CAMPAIGNCODE_NAME));

		/* read /forms.contact language from database */
		$this->a_arr_Language = array();
		$this->a_arr_Language["id"] = $this->get_field_id(FORMS_CONTACT_SETTINGS_INPUT_LANGUAGE_NAME);
		$this->a_arr_Language["name"] = $this->get_field_name(FORMS_CONTACT_SETTINGS_INPUT_LANGUAGE_NAME);
		$this->a_arr_Language["value"] = esc_attr($this->get_field_value(FORMS_CONTACT_SETTINGS_INPUT_LANGUAGE_NAME));

		/* read /forms.contact terms&conditions from database */
		$this->a_arr_TaCLink = array();
		$this->a_arr_TaCLink["id"] = $this->get_field_id(FORMS_CONTACT_SETTINGS_INPUT_TAC_NAME);
		$this->a_arr_TaCLink["name"] = $this->get_field_name(FORMS_CONTACT_SETTINGS_INPUT_TAC_NAME);
		$this->a_arr_TaCLink["value"] = esc_attr($this->get_field_value(FORMS_CONTACT_SETTINGS_INPUT_TAC_NAME));

		/* read /forms.contact protocol for terms&conditions from database */
		$this->a_arr_TaCProtocolLink = array();
		$this->a_arr_TaCProtocolLink["id"] = $this->get_field_id(FORMS_CONTACT_SETTINGS_INPUT_TAC_PROTOCOL_NAME);
		$this->a_arr_TaCProtocolLink["name"] = $this->get_field_name(FORMS_CONTACT_SETTINGS_INPUT_TAC_PROTOCOL_NAME);
		$this->a_arr_TaCProtocolLink["value"] = esc_attr($this->get_field_value(FORMS_CONTACT_SETTINGS_INPUT_TAC_PROTOCOL_NAME));

	}

	/**
	 * add admin menu for plugin settings
	 * called in class constructor
	 */
	function admin_menu()
	{
		/* current user needs the permission to update plugins */
		if (!current_user_can('update_plugins')) {
			return;
		}

		/* submenu page title */
		$l_str_PageTitle = "<span class='METHIS'>/</span>forms<span class='METHIS'>.</span>contact";
		/* submenu title */
		$l_str_MenuTitle = "<span class='METHIS'>/</span>forms<span class='METHIS'>.</span>contact";

		/* Add a new submenu to the standard Settings panel */
		$this->pagehook = $page = add_options_page( $l_str_PageTitle, $l_str_MenuTitle, 'administrator', $this->page_id, array($this, 'render'));

		/* Executed on-load. Add all metaboxes. calls function: metaboxes */
		add_action('load-' . $this->pagehook, array($this, 'metaboxes'));

		/* Include js, css, or header *only* for our settings page, calls function: js_includes */
		add_action("admin_print_scripts-$page", array($this, 'js_includes'));
		/* calls function: admin_head */
		add_action("admin_head-$page", array($this, 'admin_head'));
	}

	/**
	 * called in admin_menu()
	 */
	function admin_head()
	{
	}

	/**
	 * called in admin_menu()
	 */
	function js_includes()
	{
	}

	/**
	 * Sanitize our plugin settings array as needed.
	 * @param array $options
	 * @return array
	 */
	function sanitize_theme_options($options)
	{
		/* loop through all keys in the array and filters them */
		foreach ($options as $l_str_Key => $l_str_Value) {
			$options[$l_str_Key] = forms_contact_filter_value($l_str_Value);
		}
		return $options;
	}

	/**
	 * access settings field by name
	 * @param string $name
	 * @return string
	 */
	protected function get_field_name($name)
	{
		return sprintf('%s[%s]', $this->settings_field, $name);
	}

	/**
	 * access settings field by id
	 * @param string $id
	 * @return string
	 */
	protected function get_field_id($id)
	{
		return sprintf('%s[%s]', $this->settings_field, $id);

	}

	/**
	 * get settings field value
	 * @param string $key
	 * @return string
	 */
	protected function get_field_value($key)
	{
		return $this->options[$key];
	}

	/**
	 * Render settings page, display the page container
	 */
	function render()
	{
		global $wp_meta_boxes;
		?>

		<div class="wrap">
			<h2><span class='METHIS'>/</span>forms<span class='METHIS'>.</span>contact <?php echo __("Settings", FORMS_CONTACT_PLUGIN_NAME); ?></h2>

			<form method="post" action="options.php">
				<p>
					<input type="submit" class="button button-primary" name="save_options" value="<?php echo __("Save", FORMS_CONTACT_PLUGIN_NAME); ?>"/>
				</p>

				<div class="metabox-holder">
					<div class="postbox-container" style="width: 99%;">
						<?php
						/* Render metaboxes */
						settings_fields($this->settings_field);
						do_meta_boxes($this->pagehook, 'main', null);
						if (isset($wp_meta_boxes[$this->pagehook]['column2'])) {
							do_meta_boxes($this->pagehook, 'column2', null);
						}
						?>
					</div>
				</div>

				<p>
					<input type="submit" class="button button-primary" name="save_options" value="<?php echo __("Save", FORMS_CONTACT_PLUGIN_NAME); ?>"/>
				</p>
			</form>
		</div>

		<!-- Needed to allow metabox layout and close functionality. -->
		<script type="text/javascript">
			jQuery(document).ready(function ($) {
				// close postboxes that should be closed
				$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
				// postboxes setup
				postboxes.add_postbox_toggles('<?php echo $this->pagehook; ?>');

				jQuery("#<?php echo $this->a_arr_CampaignCode["id"]; ?>").focus();

				<?php if (!empty($this->a_arr_CampaignCode["value"])) { ?>
				jQuery("#forms-contact-payment").addClass("closed");
				jQuery("#forms-contact-preview").addClass("closed");
				<?php } ?>
			});
		</script>
	<?php
	}

	/**
	 * add containers to the settings page
	 * displayed containers on the settings page
	 */
	function metaboxes()
	{
		add_meta_box('forms-contact-general', __("General Information", FORMS_CONTACT_PLUGIN_NAME), array($this, 'info_box'), $this->pagehook, 'main');
		add_meta_box('forms-contact-settings', __("Settings", FORMS_CONTACT_PLUGIN_NAME), array($this, 'settings_box'), $this->pagehook, 'main');
		if (!empty($this->a_arr_CampaignCode["value"])) {
			add_meta_box('forms-contact-payment', __("Purchase your datasets for ease of use", FORMS_CONTACT_PLUGIN_NAME), array($this, 'payment_box'), $this->pagehook, 'main');
			add_meta_box('forms-contact-preview', __("Preview", FORMS_CONTACT_PLUGIN_NAME), array($this, 'preview_box'), $this->pagehook, 'main');
		} else {
			add_meta_box('forms-contact-order', __("Order your free contact form", FORMS_CONTACT_PLUGIN_NAME), array($this, 'order_box'), $this->pagehook, 'main');
		}
		add_meta_box('forms-contact-placeholder', __("Insert your cBound/forms.contact", FORMS_CONTACT_PLUGIN_NAME), array($this, 'placeholder_box'), $this->pagehook, 'main');
		add_meta_box('forms-contact-footer', __("Contact us", FORMS_CONTACT_PLUGIN_NAME), array($this, 'footer_box'), $this->pagehook, 'main');
	}

	/**
	 * displays the information container
	 */
	function info_box()
	{
		?>
		<p>
			<strong><?php echo __("current version:", FORMS_CONTACT_PLUGIN_NAME); ?></strong>&nbsp;&nbsp;&nbsp;V<?php echo forms_contact_plugin_metadata('Version'); ?>
		</p>
	<?php
	}

	/**
	 * displays the settings container
	 */
	function settings_box()
	{
		?>
		<!-- LandingPage ID -->
		<div class="forms_contact_container">
			<label class="settings_page_forms_contact_label forms_contact_25"
				   for="<?php echo $this->a_arr_CampaignCode["id"]; ?>"><?php echo __("cBound/forms.contact identification code:", FORMS_CONTACT_PLUGIN_NAME); ?>
			</label>
			<input type="text"
				   class="forms_contact_input_field forms_contact_75"
				   name="<?php echo $this->a_arr_CampaignCode["name"]; ?>"
				   id="<?php echo $this->a_arr_CampaignCode["id"]; ?>"
				   value="<?php echo $this->a_arr_CampaignCode["value"]; ?>"/>
		</div>

		<!-- /forms.contact language -->
		<div class="forms_contact_container">
			<label class="settings_page_forms_contact_label forms_contact_25"
				   for="<?php echo $this->a_arr_Language["id"]; ?>"><?php echo __("cBound/forms.contact language:", FORMS_CONTACT_PLUGIN_NAME); ?>
			</label>
			<select class="forms_contact_select_box forms_contact_25" id="<?php echo FORMS_CONTACT_SETTINGS_INPUT_LANGUAGE_NAME; ?>"
					name="<?php echo $this->a_arr_Language["name"]; ?>">
				<option value="en_GB">English (United Kingdom)</option>
				<option value="en_US">English (United States of America)</option>
				<option value="de_DE">Deutsch</option>
				<option value="default"><?php echo __('browser-dependent', FORMS_CONTACT_PLUGIN_NAME); ?></option>
			</select>
			<script type="text/javascript">
				jQuery(document).ready(function () {
					jQuery("#<?php echo FORMS_CONTACT_SETTINGS_INPUT_LANGUAGE_NAME; ?> option[value='<?php echo $this->a_arr_Language["value"]; ?>']").prop("selected", true);
				});
			</script>
		</div>

		<!-- terms and conditions link -->
		<div class="forms_contact_container">
			<div class="forms_contact_min forms_contact_25" style="float:left;">
				<label class="settings_page_forms_contact_label"
					   for="<?php echo $this->a_arr_TaCLink["id"]; ?>"><?php echo sprintf(__("link to your disclaimer (maximum length: %d):", FORMS_CONTACT_PLUGIN_NAME), 100); ?>
				</label>
			</div>
			<div class="forms_contact_min" style="float:left;">
				<select class="forms_contact_select_box"
						id="<?php echo FORMS_CONTACT_SETTINGS_INPUT_TAC_PROTOCOL_NAME; ?>"
						name="<?php echo $this->a_arr_TaCProtocolLink["name"]; ?>">
					<option value="http">http://</option>
					<option value="https">https://</option>
				</select>
			</div>
			<div class="forms_contact_min forms_contact_50" style="float:left;">
				<input type="text"
					   class="forms_contact_input_field forms_contact_100"
					   name="<?php echo $this->a_arr_TaCLink["name"]; ?>"
					   id="<?php echo $this->a_arr_TaCLink["id"]; ?>"
					   value="<?php echo $this->a_arr_TaCLink["value"]; ?>"
					   maxlength="100"/>
			</div>
			<div style="clear:left;"></div>
			<script type="text/javascript">
				jQuery(document).ready(function () {
					jQuery("#<?php echo FORMS_CONTACT_SETTINGS_INPUT_TAC_PROTOCOL_NAME; ?> option[value='<?php echo $this->a_arr_TaCProtocolLink["value"]; ?>']").prop("selected", true);
				});
			</script>
		</div>
	<?php
	}

	/**
	 * displays the payment container
	 */
	function payment_box()
	{
		echo forms_contact_replace_placeholders(FORMS_CONTACT_PAYMENT_PLACEHOLDER, FORMS_CONTACT_PAYMENT_PLACEHOLDER, $this->a_arr_Language["value"], $this->a_arr_TaCProtocolLink["value"] . "://" . $this->a_arr_TaCLink["value"], "payment", "todo=nothing&CampaignCode=" . $this->a_arr_CampaignCode["value"]);
	}

	/**
	 * displays the contact form (preview) container
	 */
	function preview_box()
	{
		echo forms_contact_replace_placeholders(FORMS_CONTACT_PLACEHOLDER, FORMS_CONTACT_PLACEHOLDER, $this->a_arr_Language["value"], $this->a_arr_TaCProtocolLink["value"] . "://" . $this->a_arr_TaCLink["value"], "form", "CampaignCode=" . $this->a_arr_CampaignCode["value"]);
	}

	/**
	 * displays the order form container
	 */
	function order_box()
	{
		echo forms_contact_replace_placeholders(FORMS_CONTACT_ORDER_PLACEHOLDER, FORMS_CONTACT_ORDER_PLACEHOLDER, $this->a_arr_Language["value"], $this->a_arr_TaCProtocolLink["value"] . "://" . $this->a_arr_TaCLink["value"], "order", "");
	}

	/**
	 * displays the placeholder tag container
	 */
	function placeholder_box()
	{
		?>
		<div style="text-align:center;">
			<div style="text-align:center; width:auto; display:inline-block;">
				<p><?php echo __("Insert the following shortcode where you want your cBound/forms.contact to be displayed:", FORMS_CONTACT_PLUGIN_NAME); ?></p>

				<p style="color:#2244ff;font-weight:bold;"><?php echo FORMS_CONTACT_PLACEHOLDER; ?></p>

				<p><?php echo __("The plugin replaces this shortcode automatically with your cBound/forms.contact.", FORMS_CONTACT_PLUGIN_NAME); ?></p>

				<p style="font-style:italic; font-size:11px;">
					<?php echo __("If you have any questions, please don't hesitate to contact our", FORMS_CONTACT_PLUGIN_NAME); ?>
					<a href="mailto:support@methis.at"
					   style="text-decoration:underline; cursor:pointer; color: #202020;">
						<span class="METHIS">METHIS</span> Support Team
					</a>.
				</p>
			</div>
		</div>
	<?php
	}

	/**
	 * displays the METHIS footer container
	 */
	function footer_box()
	{
		?>
		<div style="text-align:center;">
			<div style="text-align:center; width:auto; min-width:400px; display:inline-block;">
				<div style="text-align:left;">
					<p>
						<?php echo __("Sincerely", FORMS_CONTACT_PLUGIN_NAME); ?><br/>
						<?php echo __("Your", FORMS_CONTACT_PLUGIN_NAME); ?> <span class="METHIS">METHIS</span> Team
					</p>
				</div>

				<p align="center">
					<span style="font-family:arial,helvetica,sans-serif;">
						<font size="2"
							  style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; color: #000000; line-height: 14px; font-weight:normal; text-decoration:none;">
							<a href="<?php echo __("https://methis.at/en", FORMS_CONTACT_PLUGIN_NAME); ?>"
							   style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; color: #000000; line-height: 14px; font-weight:normal; text-decoration:none;"
							   target="_blank">
								<?php echo __("methis.at", FORMS_CONTACT_PLUGIN_NAME); ?>
							</a>
							&nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
							<a href="<?php echo __("https://methis.at/imprint", FORMS_CONTACT_PLUGIN_NAME); ?>"
							   style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; color: #000000; line-height: 14px; font-weight:normal; text-decoration:none;"
							   target="_blank">
								<?php echo __("imprint", FORMS_CONTACT_PLUGIN_NAME); ?>
							</a>
							&nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;
							<a href="<?php echo __("https://methis.at/en/methis/contact", FORMS_CONTACT_PLUGIN_NAME); ?>"
							   style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; color: #000000; line-height: 14px; font-weight:normal; text-decoration:none;"
							   target="_blank">
								<?php echo __("contact", FORMS_CONTACT_PLUGIN_NAME); ?>
							</a>
						</font>
					</span>
				</p>

				<div align="center" bgcolor="#FFFFFF">
					<span style="font-family:arial,helvetica,sans-serif;">
						<font size="1"
							  style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; line-height: 14px; color: #000000; text-decoration:none; font-weight:normal;">
							<span style="color: rgb(226, 35, 26);">METHIS</span> Dialogmarketing GmbH,<br/>
							Vogelweiderstrasse 44a, 5020 Salzburg
						</font>
					</span>
				</div>
			</div>
		</div>
	<?php
	}

} /* Class forms_contact_class_settings */